summaryrefslogtreecommitdiffstats
path: root/korganizer/incidencechanger.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'korganizer/incidencechanger.cpp')
-rw-r--r--korganizer/incidencechanger.cpp52
1 files changed, 26 insertions, 26 deletions
diff --git a/korganizer/incidencechanger.cpp b/korganizer/incidencechanger.cpp
index 1ffcc628..8b922034 100644
--- a/korganizer/incidencechanger.cpp
+++ b/korganizer/incidencechanger.cpp
@@ -18,8 +18,8 @@
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
As a special exception, permission is given to link this program
- with any edition of Qt, and distribute the resulting executable,
- without including the source code for Qt in the source distribution.
+ with any edition of TQt, and distribute the resulting executable,
+ without including the source code for TQt in the source distribution.
*/
#include "incidencechanger.h"
@@ -55,7 +55,7 @@ bool IncidenceChanger::beginChange( Incidence *incidence,
bool IncidenceChanger::sendGroupwareMessage( Incidence *incidence,
KCal::Scheduler::Method method,
KOGlobals::HowChanged action,
- TQWidget *parent )
+ TQWidget *tqparent )
{
if ( KOPrefs::instance()->thatIsMe( incidence->organizer().email() ) && incidence->attendeeCount()>0
&& !KOPrefs::instance()->mUseGroupwareCommunication ) {
@@ -63,7 +63,7 @@ bool IncidenceChanger::sendGroupwareMessage( Incidence *incidence,
return true;
} else if( KOPrefs::instance()->mUseGroupwareCommunication ) {
return
- KOGroupware::instance()->sendICalMessage( parent, method, incidence, action, false );
+ KOGroupware::instance()->sendICalMessage( tqparent, method, incidence, action, false );
}
return true;
}
@@ -111,12 +111,12 @@ bool IncidenceChanger::endChange( Incidence *incidence,
return calRes->endChange( incidence, res, subRes );
}
-bool IncidenceChanger::deleteIncidence( Incidence *incidence, TQWidget *parent )
+bool IncidenceChanger::deleteIncidence( Incidence *incidence, TQWidget *tqparent )
{
if ( !incidence ) return true;
kdDebug(5850)<<"IncidenceChanger::deleteIncidence for incidence \""<<incidence->summary()<<"\""<<endl;
bool doDelete = sendGroupwareMessage( incidence, KCal::Scheduler::Cancel,
- KOGlobals::INCIDENCEDELETED, parent );
+ KOGlobals::INCIDENCEDELETED, tqparent );
if( doDelete ) {
// @TODO: let Calendar::deleteIncidence do the locking...
Incidence* tmp = incidence->clone();
@@ -132,7 +132,7 @@ kdDebug(5850)<<"IncidenceChanger::deleteIncidence for incidence \""<<incidence->
if ( me->status() == KCal::Attendee::Accepted || me->status() == KCal::Attendee::Delegated )
notifyOrganizer = true;
Attendee *newMe = new Attendee( *me );
- newMe->seStatus( KCal::Attendee::Declined );
+ newMe->setqStatus( KCal::Attendee::Declined );
tmp->clearAttendees();
tmp->addAttendee( newMe );
break;
@@ -152,7 +152,7 @@ kdDebug(5850)<<"IncidenceChanger::deleteIncidence for incidence \""<<incidence->
}
bool IncidenceChanger::cutIncidences( const Incidence::List &incidences,
- TQWidget *parent )
+ TQWidget *tqparent )
{
Incidence::List::ConstIterator it;
bool doDelete = true;
@@ -160,7 +160,7 @@ bool IncidenceChanger::cutIncidences( const Incidence::List &incidences,
for ( it = incidences.constBegin(); it != incidences.constEnd(); ++it ) {
if ( *it ) {
doDelete = sendGroupwareMessage( *it, KCal::Scheduler::Cancel,
- KOGlobals::INCIDENCEDELETED, parent );
+ KOGlobals::INCIDENCEDELETED, tqparent );
if ( doDelete ) {
emit incidenceToBeDeleted( *it );
incsToCut.append( *it );
@@ -180,11 +180,11 @@ bool IncidenceChanger::cutIncidences( const Incidence::List &incidences,
}
}
-bool IncidenceChanger::cutIncidence( Incidence *incidence, TQWidget *parent )
+bool IncidenceChanger::cutIncidence( Incidence *incidence, TQWidget *tqparent )
{
Incidence::List incidences;
incidences.append( incidence );
- return cutIncidences( incidences, parent );
+ return cutIncidences( incidences, tqparent );
}
class IncidenceChanger::ComparisonVisitor : public IncidenceBase::Visitor
@@ -327,14 +327,14 @@ bool IncidenceChanger::myAttendeeStatusChanged( Incidence *oldInc, Incidence *ne
bool IncidenceChanger::changeIncidence( Incidence *oldinc, Incidence *newinc,
KOGlobals::WhatChanged action,
- TQWidget *parent )
+ TQWidget *tqparent )
{
- return changeIncidence( oldinc, newinc, action, parent, 0 );
+ return changeIncidence( oldinc, newinc, action, tqparent, 0 );
}
bool IncidenceChanger::changeIncidence( Incidence *oldinc, Incidence *newinc,
KOGlobals::WhatChanged action,
- TQWidget *parent,
+ TQWidget *tqparent,
int dontAskForGroupware )
{
kdDebug(5850)<<"IncidenceChanger::changeIncidence for incidence \""<<newinc->summary()<<"\" ( old one was \""<<oldinc->summary()<<"\")"<<endl;
@@ -353,7 +353,7 @@ kdDebug(5850)<<"IncidenceChanger::changeIncidence for incidence \""<<newinc->sum
bool success = true;
if ( KOPrefs::instance()->mUseGroupwareCommunication ) {
success = KOGroupware::instance()->sendICalMessage(
- parent,
+ tqparent,
KCal::Scheduler::Request,
newinc, KOGlobals::INCIDENCEEDITED, attendeeStatusChanged, dontAskForGroupware );
}
@@ -372,19 +372,19 @@ kdDebug(5850)<<"IncidenceChanger::changeIncidence for incidence \""<<newinc->sum
bool IncidenceChanger::addIncidence( Incidence *incidence,
ResourceCalendar *res, const TQString &subRes,
- TQWidget *parent )
+ TQWidget *tqparent )
{
- return addIncidence( incidence, res, subRes, parent, 0 );
+ return addIncidence( incidence, res, subRes, tqparent, 0 );
}
bool IncidenceChanger::addIncidence( Incidence *incidence,
ResourceCalendar *res, const TQString &subRes,
- TQWidget *parent, int dontAskForGroupware )
+ TQWidget *tqparent, int dontAskForGroupware )
{
CalendarResources *stdcal = dynamic_cast<CalendarResources *>( mCalendar );
if( stdcal && !stdcal->hasCalendarResources() ) {
KMessageBox::sorry(
- parent,
+ tqparent,
i18n( "No calendars found, unable to save %1 \"%2\"." ).
arg( i18n( incidence->type() ) ).
arg( incidence->summary() ) );
@@ -392,14 +392,14 @@ bool IncidenceChanger::addIncidence( Incidence *incidence,
return false;
}
// FIXME: This is a nasty hack, since we need to set a parent for the
// resource selection dialog. However, we don't have any UI methods
// in the calendar, only in the CalendarResources::DestinationPolicy
// So we need to type-cast it and extract it from the CalendarResources
- TQWidget *tmpparent = 0;
+ TQWidget *tmptqparent = 0;
if ( stdcal ) {
- tmpparent = stdcal->dialogParentWidget();
- stdcal->setDialogParentWidget( parent );
+ tmptqparent = stdcal->dialogParentWidget();
+ stdcal->setDialogParentWidget( tqparent );
}
// If a ResourceCalendar isn't provided, then try to compute one
@@ -445,7 +445,7 @@ bool IncidenceChanger::addIncidence( Incidence *incidence,
arg( incidence->summary() ).
arg( pResName );
}
- KMessageBox::sorry( parent, errMessage );
+ KMessageBox::sorry( tqparent, errMessage );
}
kdDebug(5850) << "IncidenceChanger: Can't add incidence" << endl;
return false;
@@ -453,11 +453,11 @@ bool IncidenceChanger::addIncidence( Incidence *incidence,
if ( KOPrefs::instance()->mUseGroupwareCommunication ) {
if ( !KOGroupware::instance()->sendICalMessage(
- parent,
+ tqparent,
KCal::Scheduler::Request,
incidence, KOGlobals::INCIDENCEADDED, false, dontAskForGroupware ) ) {
KMessageBox::sorry(
- parent,
+ tqparent,
i18n( "Attempt to send the scheduling message failed. "
"Please check your Group Scheduling settings. "
"Contact your system administrator for more help.") );
@@ -392,14 +392,14 @@ bool IncidenceChanger::addIncidence( Incidence *incidence,
return false;
}
- // FIXME: This is a nasty hack, since we need to set a parent for the
+ // FIXME: This is a nasty hack, since we need to set a tqparent for the
// resource selection dialog. However, we don't have any UI methods
// in the calendar, only in the CalendarResources::DestinationPolicy